/*++
/* NAME
/*	linked_list 3h
/* SUMMARY
/*	module for manipulating a linked list of distributed hosts
/* SYNOPSYS
/*	#include <linked_list.h>
/* DESCRIPTION
/* LICENSE
/* .ad
/* .fi
/*	The dscan license must be distributed with this software.
/* AUTHOR(s)
/*	Intrinsic <intrinsic@hushmail.com>, Ni9 Technologies
/*--*/

#ifndef __LINKED_LIST_H
#define __LINKED_LIST_H

/*
 * Macro used to initialize a list of distributed hosts.
 */
#define DHOST_LIST_INIT(l)            l.num_dhosts = 0;                       \
                                      l.head = NULL;                          \
                                      l.tail = NULL;

/*
 * Structure to hold an element, a distributed host, in the linked list.
 */
struct dhost_s {
	char	*hostname;                         /* hostname */
	unsigned long addr;                        /* address */
	unsigned int port;                         /* port */
	int	sock;                              /* socket */
	struct dhost_s *next;                      /* next distributed host */
	struct dhost_s *prev;                      /* previous distributed
	                                            * host */
};

/*
 * Structure to hold a linked list.
 */
struct dhost_list_s {
	int	num_dhosts;                        /* number of distributed
	                                            * hosts in the list */
	struct dhost_s *head;                      /* head of the list */
	struct dhost_s *tail;                      /* tail of the list */
};

extern int add_dhost(struct dhost_list_s *, char *, unsigned int);
extern int del_dhost(struct dhost_list_s *, char *);

#endif
