/*++
/* NAME
/*	network 3
/* SUMMARY
/*	module to perform network functions needed by dscan and dscand
/* SYNOPSYS
/*	#include <network.h>
/*
/*	unsigned long get_ip(hostname)
/*	char	*hostname;
/*
/*	int	scan_port(packet)
/*	struct dscanp_packet_s packet;
/*
/*	int	connect_scan(packet)
/*	struct dscanp_packet_s packet;
/* DESCRIPTION
/*	get_ip() returns the numerical IP address of hostname on success and -1
/* 	on failure.
/*
/*	scan_port() is used to determine what scan function to execute depending
/*	on the scan type, returns one of the PACKET_SCAN variables.
/*
/*	connect_scan() is used to conduct a "vanila" or connect scan on a port,
/*	returns one of the PACKET_SCAN variables.
/* LICENSE
/* .ad
/* .fi
/*	The dscan license must be distributed with this software.
/* AUTHOR(S)
/*	Intrinsic <intrinsic@hushmail.com>, Ni9 Technologies
/*--*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <network.h>

unsigned long get_ip(char *hostname)
{
	struct hostent *host_info;

	if((host_info = gethostbyname(hostname)) == NULL)
		return(-1);

	return(inet_addr(inet_ntoa(*((struct in_addr *) host_info->h_addr))));
}

int	scan_port(struct dscanp_packet_s packet)
{
	switch(packet.scan) {
	case PACKET_SCAN_CONNECT:
		return(connect_scan(packet));
	default:
		return(PACKET_REPLY_FAILURE);
	}
}

int	connect_scan(struct dscanp_packet_s packet)
{
	int	sock;
	unsigned long ip_address;
	struct sockaddr_in sock_info;

	/*
	 * Get the IP address of the machine to scan in a useable form.
	 */
	if(packet.resolved == PACKET_RESOLVED_YES)
		ip_address = inet_addr(packet.host);
	else if(packet.resolved == PACKET_RESOLVED_NO) {
		if((ip_address = get_ip(packet.host)) == -1)
			return(PACKET_REPLY_FAILURE);
	} else
		return(PACKET_REPLY_FAILURE);
		
	sock_info.sin_family = AF_INET;
	sock_info.sin_addr.s_addr = ip_address;
	sock_info.sin_port = htons(packet.port);

	/*
	 * Try connecting to the host and send the results back to the client.
	 */
	if(packet.protocol == PACKET_PROTOCOL_TCP) {
		if((sock = socket(AF_INET, SOCK_STREAM, 0)) < 0)
			return(PACKET_REPLY_FAILURE);

		if(connect(sock, (struct sockaddr *) &sock_info,
		  sizeof(sock_info)) < 0) {
			close(sock);
			return(PACKET_REPLY_CLOSED);
		} 

		close(sock);
		return(PACKET_REPLY_OPEN);
	} else if(packet.protocol == PACKET_PROTOCOL_UDP) {
		/* XXX - Currently not implemented */
		return(PACKET_REPLY_UNIMP);
	} else
		return(PACKET_REPLY_FAILURE);
}
