/*++
/* NAME
/*	network 3h
/* SUMMARY
/*	module to perform network functions needed by dscan and dscand
/* SYNOPSYS
/*	#include <network.h>
/* DESCRIPTION
/* LICENSE
/* .ad
/* .fi
/*	The dscan license must be distributed with this software.
/* AUTHOR(S)
/*	Intrinsic <intrinsic@hushmail.com>, Ni9 Technologies
/*--*/

#ifndef __NETWORK_H
#define __NETWORK_H

#define LENGTH_HOST                    512
#define LENGTH_PACKET                  (LENGTH_HOST + 32)

/*
 * Macros for constructing and deconstructing packets, DECONSTRUCT_PACKET will
 * return less than DECONSTRUCT_PACKET_SUCCESS on failure.
 */
#define CONSTRUCT_PACKET(p, b)         snprintf(b, LENGTH_PACKET - 1, "%d %d "\
                                         "%s %d %d %d %d", p.type, p.resolved,\
                                         p.host, p.port, p.protocol, p.scan,  \
                                         p.reply)
#define CONSTRUCT_PACKET_SPRINTF(p, b) sprintf(b, "%d %d %s %d %d %d %d",     \
                                         p.type, p.resolved, p.host, p.port,  \
                                         p.protocol, p.scan, p.reply)
#define DECONSTRUCT_PACKET_SUCCESS     7
#define DECONSTRUCT_PACKET(p, b)       sscanf(b, "%d %d %s %d %d %d %d",      \
                                         &p.type, &p.resolved, &p.host,       \
                                         &p.port, &p.protocol, &p.scan,       \
                                         &p.reply)

/*
 * Structure to hold a DSCANP (distributed [port] scanner protocol) packet.
 */
struct dscanp_packet_s {
	int	type;
#define PACKET_TYPE_REQUEST            1
#define PACKET_TYPE_REPLY              2
	int	resolved;
#define PACKET_RESOLVED_YES            1
#define PACKET_RESOLVED_NO             2
	char	host[LENGTH_HOST];
	unsigned int port;
	int	protocol;
#define PACKET_PROTOCOL_TCP            1
#define PACKET_PROTOCOL_UDP            2
	int	scan;
#define PACKET_SCAN_CONNECT            1
	int	reply;
#define PACKET_REPLY_NULL              0
#define PACKET_REPLY_OPEN              1
#define PACKET_REPLY_CLOSED            2
#define PACKET_REPLY_FAILURE           3
#define PACKET_REPLY_UNIMP             4
};

extern unsigned long get_ip(char *);
extern int scan_port(struct dscanp_packet_s);
extern int connect_scan(struct dscanp_packet_s);

#endif
