/*++
/* NAME
/*	pid_file 3
/* SUMMARY
/*	module for manipulating the file containing the current pid
/* SYNOPSYS
/*	#include <pid_file.h>
/*
/*	pid_t	pid_file_check(pid_path)
/*	char	*pid_path;
/*
/*	int	pid_file_write(pid_path)
/*	char	*pid_path;
/*
/*	int	pid_file_delete(pid_path)
/*	char	*pid_path;
/* DESCRIPTION
/*	pid_file_check() checks for the existence of a file containing the
/*	the pid, if none is found then the function returns -1 and if one is
/*	found then the function returns the pid held in the file.  If the
/*	pid could not be read from the file then the function returns -1.
/*
/*	pid_file_write() writes the current pid, gained using the getpid(),
/*	function to the pid file, the function returns -1 if the pid file could
/*	not be opened for writing and 0 on success.
/*
/*	pid_file_delete() removes the pid file, the function returns -1 on
/*	failure and 0 on success.
/* DIAGNOSTICS
/* LICENSE
/* .ad
/* .fi
/*	The dscan license must be distributed with this software.
/* AUTHOR(S)
/*	Intrinsic <intrinsic@hushmail.com>, Ni9 Technologies
/*--*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <pid_file.h>

pid_t	pid_file_check(char *pid_path)
{
	pid_t	pid;
	FILE	*pid_fd;

	if((pid_fd = fopen(pid_path, "r")) == NULL)
		return(-1);
		
	if(fscanf(pid_fd, "%d", &pid) < 1)
		return(-1);
		
	fclose(pid_fd);
	return(pid);
}

int	pid_file_write(char *pid_path)
{
	FILE	*pid_fd;

	if((pid_fd = fopen(pid_path, "w")) == NULL)
		return(-1);

	fprintf(pid_fd, "%d", getpid());

	fclose(pid_fd);
	return(0);
}

int	pid_file_delete(char *pid_path)
{
	return(unlink(pid_path));
}
